@@ -917,8 +917,10 @@ std::vector<std::string> voms::GetTargets()
                                         name->name->d.ia5->length));
       }
     }
+    AC_TARGETS_free(target);
   }
 
+  AC_free(ac);
   return targets;
 }
 
@@ -937,12 +939,15 @@ bool vomsdata::LoadCredentials(X509 *cert, EVP_PKEY *pkey, STACK_OF(X509) *chain
   if (!data)
     return false;
 
-  if (cert)
+  if (cert) {
+    X509_free(data->cert);
     data->cert = X509_dup(cert);
+  }
 
-  if (pkey)
+  if (pkey) {
+    EVP_PKEY_free(data->key);
     data->key = EVP_PKEY_dup(pkey);
-
+  }
 
   /* sk_dup does *not* duplicate the stack content.  Only the
      stack itself. */
