@@ -175,17 +175,21 @@ std::string GSISocketClient::GetError()
 bool 
 GSISocketClient::post_connection_check(SSL *ssl)
 {
+  bool ret = true;
+
   X509 *peer_cert = SSL_get_peer_certificate(ssl);
   if (!peer_cert)
-    return false;
-
-  char *name = X509_NAME_oneline(X509_get_subject_name(peer_cert), NULL, 0);
-  peer_subject = std::string(name);
-  OPENSSL_free(name);
+    ret = false;
+  else {
+    char *name = X509_NAME_oneline(X509_get_subject_name(peer_cert), NULL, 0);
+    peer_subject = std::string(name);
+    OPENSSL_free(name);
+  }
 
   //  peer_subject = _server_contact.empty() ? "" : _server_contact; 
   //  get_peer_data(context, version, &peer_key, &tmp, &peer_cert);
-  return true;
+  X509_free(peer_cert);
+  return ret;
 }
 
 
@@ -452,6 +456,8 @@ GSISocketClient::Open()
 
  err:
   destroy_SSL_proxy_handler(ssl);
+  if (ssl)
+    SSL_clear(ssl);
   SSL_free(ssl);
   SSL_CTX_free(ctx);
   BIO_free(conn);
@@ -480,7 +486,8 @@ GSISocketClient::Close()
     cert_chain = NULL;
 
     //    SSL_shutdown(ssl);
-    SSL_clear(ssl);
+    if (ssl)
+      SSL_clear(ssl);
     destroy_SSL_proxy_handler(ssl);
     SSL_free(ssl);
     SSL_CTX_free(ctx);
