@@ -97,16 +97,12 @@ int myPROXYPOLICY_set_policy(myPROXYPOLICY * proxypolicy, unsigned char * policy
 
   if(policy != NULL) {
 
-    /* perch questa copia? */
-    unsigned char * copy = malloc(length);
-    memcpy(copy, policy, length);
-
     /* if member policy of proxypolicy non set */
     if(!proxypolicy->policy)
       proxypolicy->policy = ASN1_OCTET_STRING_new();
       
     /* set member policy of proxypolicy */
-    ASN1_OCTET_STRING_set(proxypolicy->policy, copy, length);
+    ASN1_OCTET_STRING_set(proxypolicy->policy, policy, length);
 
   }
   
@@ -479,7 +475,7 @@ void InitProxyCertInfoExtension(int full)
   set = 1;
 
   /* Proxy Certificate Extension's related objects */
-  if (OBJ_obj2nid(OBJ_txt2obj(PROXYCERTINFO_V3,1)) == 0) {
+  if (my_txt2nid(PROXYCERTINFO_V3) == 0) {
     ERR_clear_error();
     OBJC(PROXYCERTINFO_V3, "Proxy Certificate Information");
     if (full) {
@@ -505,7 +501,7 @@ void InitProxyCertInfoExtension(int full)
     }
   }
 
-  if (OBJ_obj2nid(OBJ_txt2obj(PROXYCERTINFO_V4,1)) == 0) {
+  if (my_txt2nid(PROXYCERTINFO_V4) == 0) {
     ERR_clear_error();
     OBJC(PROXYCERTINFO_V4, "Proxy Certificate Information");
     if (full) {
